summaryrefslogtreecommitdiffstats
path: root/kig/misc/kigfiledialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'kig/misc/kigfiledialog.h')
-rw-r--r--kig/misc/kigfiledialog.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/kig/misc/kigfiledialog.h b/kig/misc/kigfiledialog.h
index 8c243131..5fb65949 100644
--- a/kig/misc/kigfiledialog.h
+++ b/kig/misc/kigfiledialog.h
@@ -28,6 +28,7 @@ class KigFileDialog
: public KFileDialog
{
Q_OBJECT
+ TQ_OBJECT
private:
/**
@@ -45,17 +46,17 @@ public:
* documentation of KFileDialog for more help about this
* \param filter the filter for the file dialog
* \param caption the caption of this file dialog
* \param parent the parent for this file dialog
*/
KigFileDialog( const TQString& startDir, const TQString& filter,
- const TQString& caption, TQWidget *parent );
+ const TQString& caption, TQWidget *tqparent );
/**
* Use this to set the widget containing the options of eg an export filter.
* The option widget will be popped up in a dialog right after the user
* presses OK and before the dialog is closed.
*
* You can construct the option widget with no parent, as it will be
* reparented.
*
* \param w the option widget
@@ -45,17 +46,17 @@ public:
* \param filter the filter for the file dialog
* \param caption the caption of this file dialog
- * \param parent the parent for this file dialog
+ * \param tqparent the tqparent for this file dialog
*/
KigFileDialog( const TQString& startDir, const TQString& filter,
@@ -45,17 +46,17 @@ public:
* presses OK and before the dialog is closed.
*
- * You can construct the option widget with no parent, as it will be
+ * You can construct the option widget with no tqparent, as it will be
* reparented.
*